# Seligimus
[![PyPI version](https://badge.fury.io/py/seligimus.svg)](https://badge.fury.io/py/seligimus)
![Test Python Code](https://github.com/AustinScola/seligimus/workflows/Test%20Python%20Code/badge.svg)
![Build and Test Python distrubutions](https://github.com/AustinScola/seligimus/workflows/Build%20and%20Test%20Python%20distrubutions/badge.svg)

A mono-library.

## Name Etymology

The word "seligimus" means "we select" in Latin.
